@@ -3,7 +3,7 @@ OXASL DEBLUR
 
 Copyright (c) University of Oxford 2018
 """
-from .deblur import deblur
+from .deblur import Options, run
 from ._version import __version__, __timestamp__
 
-__all__ = ["__version__", "__timestamp__", "deblur"]
+__all__ = ["__version__", "__timestamp__", "Options", "run"]
